==> admyral-0.1.3-py3-none-any.whl: CONTRIBUTING.md <==
# Contributing to Admyral

First off, thanks for taking the time to contribute! ❤️

The best ways to contribute to Admyral:

-   Suggest new ideas in our [Discord community](https://discord.gg/GqbJZT9Hbf)
-   Create and comment on [Issues](https://github.com/Admyral-Security/admyral/issues)
-   Open a PR

We welcome contributions through GitHub pull requests. This document outlines our conventions regarding development workflow, commit message formatting, contact points, and other resources. Our goal is to simplify the process and ensure that your contributions are easily accepted.

We gratefully welcome improvements to documentation, the core application, and integrations.

The maintainers are available on [Discord](https://discord.gg/GqbJZT9Hbf) in case you have any questions.

> And if you like the project, but just don't have time to contribute code, that's fine. There are other easy ways to support the project and show your appreciation, which we would also be very happy about:
>
> -   Star the project;
> -   Tweet about it;
> -   Refer to this project in your project's readme;
> -   Submit ideas in the [Discord](https://discord.gg/GqbJZT9Hbf);
> -   Create and comment on [Issues](https://github.com/Admyral-Security/admyral/issues);
> -   Mention the project at local meetups and tell your friends/colleagues.

## Development Setup

For development setup, please refer to our documentation on [Admyral Docs](https://docs.admyral.dev/setup/dev).

## Making a change

_Before making any significant changes, please [open an issue](https://github.com/Admyral-Security/admyral/issues)._ Discussing your proposed changes ahead of time will make the contribution process smooth for everyone. Large changes that were not discussed in an issue may be rejected.

Once we've discussed your changes and you've got your code ready, make sure that tests are passing and open your pull request.

A good first step is to search for open [issues](https://github.com/Admyral-Security/admyral/issues). Issues are labeled, and some good issues to start with are labeled: good first issue.

## License

Admyral is Apache 2.0 licensed. See [LICENSE](LICENSE) and [docs](https://docs.admyral.dev/open-source) for more details.

When contributing to the Admyral codebase, you need to agree to the [Contributor License Agreement](https://cla-assistant.io/Admyral-Security/admyral). You only need to do this once and the CLA bot will remind you if you haven't signed it yet.

## Attribution

This Contribution Guideline is based on [Langfuse](https://langfuse.com/).

==> admyral-0.1.26-py3-none-any.whl: CONTRIBUTING.md <==
# Contributing to Admyral

First off, thanks for taking the time to contribute! ❤️

The best ways to contribute to Admyral:

-   Suggest new ideas in our [Discord community](https://discord.gg/GqbJZT9Hbf)
-   Create and comment on [Issues](https://github.com/Admyral-Security/admyral/issues)
-   Open a PR

We welcome contributions through GitHub pull requests. This document outlines our conventions regarding development workflow, commit message formatting, contact points, and other resources. Our goal is to simplify the process and ensure that your contributions are easily accepted.

We gratefully welcome improvements to documentation, the core application, and integrations.

The maintainers are available on [Discord](https://discord.gg/GqbJZT9Hbf) in case you have any questions.

> And if you like the project, but just don't have time to contribute code, that's fine. There are other easy ways to support the project and show your appreciation, which we would also be very happy about:
>
> -   Star the project;
> -   Tweet about it;
> -   Refer to this project in your project's readme;
> -   Submit ideas in the [Discord](https://discord.gg/GqbJZT9Hbf);
> -   Create and comment on [Issues](https://github.com/Admyral-Security/admyral/issues);
> -   Mention the project at local meetups and tell your friends/colleagues.

## Development Setup

For development setup, please refer to our documentation on [Admyral Docs](https://docs.admyral.dev/development_setup).

## Making a change

_Before making any significant changes, please [open an issue](https://github.com/Admyral-Security/admyral/issues)._ Discussing your proposed changes ahead of time will make the contribution process smooth for everyone. Large changes that were not discussed in an issue may be rejected.

Once we've discussed your changes and you've got your code ready, make sure that tests are passing and open your pull request.

A good first step is to search for open [issues](https://github.com/Admyral-Security/admyral/issues). Issues are labeled, and some good issues to start with are labeled: good first issue.

## License

Admyral is Apache 2.0 licensed. See [LICENSE](LICENSE) and [docs](https://docs.admyral.dev/open-source) for more details.

When contributing to the Admyral codebase, you need to agree to the [Contributor License Agreement](https://cla-assistant.io/Admyral-Security/admyral). You only need to do this once and the CLA bot will remind you if you haven't signed it yet.

## Attribution

This Contribution Guideline is based on [Langfuse](https://langfuse.com/).
